@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.0832'; 
+our $VERSION = '1.084'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -833,6 +833,11 @@ sub submit_comment {
     return $result->{data}{things}[0]{data}{id};
 }
 
+sub comment {
+	my($self, $parent, $text) = @_;
+	return $self->submit_comment(parent_id=>$parent, text=>$text);
+}
+
 #===============================================================================
 # Private messages
 #===============================================================================
@@ -947,7 +952,7 @@ B<The official documentation can be found at> L<http://redditclient.readthedocs.
 
     # Create a Reddit::Client object and authorize in one step
     my $reddit = new Reddit::Client(
-	user_agent 	=> 'MyScriptName 0.5 by /u/earth-tone',
+	user_agent 	=> 'MyScriptName 1.0 by /u/earth-tone',
 	client_id	=> $client_id,
 	secret		=> $secret,
 	username	=> $username,
@@ -1014,28 +1019,74 @@ To get Oauth keys, visit your apps page: L<https://www.reddit.com/prefs/apps>. C
 
 Every account that uses this script must have permission to use it. So for example if you were to check the inboxes of your various accounts, each one would need permission. To add accounts click "add developer" on the right, after you've created the app.
 
+=head1 Constants
+
+    DEFAULT_LIMIT           => 25
+    
+    VIEW_HOT                => ''
+    VIEW_NEW                => 'new'
+    VIEW_CONTROVERSIAL      => 'controversial'
+    VIEW_TOP                => 'top'
+    VIEW_RISING             => 'rising'
+    VIEW_DEFAULT            => VIEW_HOT
+    
+    VOTE_UP                 => 1
+    VOTE_DOWN               => -1
+    VOTE_NONE               => 0
+    
+    SUBMIT_LINK             => 'link'
+    SUBMIT_SELF             => 'self'
+    SUBMIT_MESSAGE          => 'message'
+    
+    MESSAGES_INBOX          => 'inbox'
+    MESSAGES_UNREAD         => 'unread'
+    MESSAGES_SENT           => 'sent'
+    MESSAGES_MESSAGES       => 'messages'
+    MESSAGES_COMMENTREPLIES => 'comments'
+    MESSAGES_POSTREPLIES    => 'selfreply'
+    MESSAGES_MENTIONS       => 'mentions'
+    
+    SUBREDDITS_HOME         => ''
+    SUBREDDITS_MINE         => 'subscriber'
+    SUBREDDITS_POPULAR      => 'popular'
+    SUBREDDITS_NEW          => 'new'
+    SUBREDDITS_CONTRIB      => 'contributor'
+    SUBREDDITS_MOD          => 'moderator'
+    
+    USER_OVERVIEW           => 'overview'
+    USER_COMMENTS           => 'comments'
+    USER_SUBMITTED          => 'submitted'
+    USER_GILDED             => 'gilded'
+    USER_UPVOTED            => 'upvoted'
+    USER_DOWNVOTED          => 'downvoted'
+    USER_HIDDEN             => 'hidden'
+    USER_SAVED              => 'saved'
+
 =head1 Methods
 
 These are the methods of the Reddit::Client class.
 
 Two notes about methods that return lists of things:
 
-1. All methods that return lists of things return them as a Perl _list_-- that is, a reference to an anonymous array. In practice this means that you get at the values with `@$array` instead of `@array`.
+1. All methods that return lists of things return them as a Perl list-- that is, a reference to an anonymous array. In practice this means that you get at the values with C<@$array> instead of C<@array>.
 
-2. All methods that return lists of things accept three optional parameters: `limit`, `before`, and `after`. You may recognize them from your address bar when viewing pages after the front page. 
-
-
-B<limit> I<integer> How many things to return. Default 25, maximum 100. If `limit` is present but false, this is interpreted as "no limit" and the max is returned.
-
-B<before> I<fullname> Return results that occur before `fullname`. Used for pagination.
-
-B<after> I<fullname> Return results that occur after `fullname`. Used for pagination. 
+2. All methods that return lists of things accept three optional parameters: I<limit>, I<before>, and I<after>. You may recognize them from your address bar when viewing pages after the front page. I<limit> defaults to 25 with a maximum of 100. (If I<limit> is present but false, this is interpreted as "no limit" and the maximum is returned.) I<before> and I<after> limit results to those posted before I<before> and after I<after>.
 
 
 =head1 Methods
 
 =over
 
+=item comment
+
+    comment ( $fullname, $text )
+	
+Make a comment under I<$fullname>, which must be either a post or a comment. Return the fullname of the new comment.
+
+This function is an alias for C<submit_comment>, and is equivalent to
+
+    submit_comment ( parent_id => $fullname, text => $text )
+
 =item delete 
 
     delete ( $fullname )
@@ -1047,64 +1098,64 @@ Delete a post or comment.
     edit_wiki ( subreddit => $subreddit, page => $page, content => $content,
 	            [ previous => $previous_version_number,] [ reason => $edit_reason, ] )
 	
-* `page` is the page being edited.
+I<page> is the page being edited.
 
-* `content` is the new page content. Can be empty but must be defined. Maximum 524,288 characters.
+I<content> is the new page content. Can be empty but must be defined. Maximum 524,288 characters.
 
-* `reason` is the edit reason. Max 256 characters, will be truncated if longer. Optional.
+I<reason> is the edit reason. Max 256 characters, will be truncated if longer. Optional.
 	
-* `previous` is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing. Optional.
+I<previous> is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing. Optional.
 
 =item find_subreddits
 
     find_subreddits ( q => $query, [ sort => 'relevance' ,] 
                       [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
 
-Returns a list of Subreddit objects matching the search string `$query`. Optionally sort them by `sort`, which can be "relevance" or "activity".
+Returns a list of Subreddit objects matching the search string I<$query>. Optionally sort them by I<sort>, which can be "relevance" or "activity".
 
 =item get_comment 
 
     get_comment ( $fullname )
 
-Returns a Comment object for `$fullname`.
+Returns a Comment object for I<$fullname>.
 
 =item get_flair_options
 
     get_flair_options( subreddit => $subreddit, post_id => $post_id_or_fullname, username => $username )
 	
-Return the flair options for either the post or the user provided.
+Get the flair options for either the post or the user provided.
 
 Returns a hash containing two keys:
 
-* `choices` is an array of hash references containing the flair options. Most important is `flair_template_id`, which is used to set the flair of a post or user with set_post_flair or set_user_flair. `flair_text` contains the text of the flair.
+1. I<choices> is an array of hash references containing the flair options. Most important is I<flair_template_id>, which is used to set the flair of a post or user with C<set_post_flair> or C<set_user_flair>. I<flair_text> contains the text of the flair.
 
-* `current` is a hash of the post or user's existing flair.
+2. I<current> is a hash of the post or user's existing flair.
 
 =item get_inbox 
 
     get_inbox ( [ view => MESSAGES_INBOX ,] [ limit => DEFAULT_LIMIT ,]
                 [ before => undef ,] [ after => undef ,] )
 				
-Returns a list of [Message](classes/message) objects, where `view` is one of the MESSAGE [constants](constants). All arguments are optional. If all are omitted your default inbox will be returned-- what you would see if you went to reddit.com and clicked the mailbox icon.
+Returns a list of Message objects, where I<view> is one of the MESSAGE constants. All arguments are optional. If all are omitted your default inbox will be returned-- what you would see if you went to reddit.com and clicked the mailbox icon.
 
-Checking your inbox via the API doesn't mark it as read. To do that you'll need to call `mark_inbox_read`: L<http://redditclient.readthedocs.org/en/latest/main-methods/#mark_inbox_read>
+Checking your inbox via the API doesn't mark it as read. To do that you'll need to call C<mark_inbox_read>: L<http://redditclient.readthedocs.org/en/latest/main-methods/#mark_inbox_read>
 
 =item get_link 
 
     get_link ( $fullname )
 
-Returns a Link object for `$fullname`.
+Returns a Link object for I<$fullname>.
 
 =item get_links
 
     get_links ( [ subreddit => undef ,] [ view => VIEW_DEFAULT ,] [ limit => DEFAULT_LIMIT ,]
                 [ before => undef ,] [ after => undef ,] )
 
-Returns a list of [Link](classes/link) objects. All arguments are optional.
+Returns a list of Link objects. All arguments are optional.
 
-`subreddit` can be a subreddit or multi (ex: "pics+funny"). If omitted, results from the user's front page will be returned-- i.e. what you would see if you visited reddit.com as that user. 
+I<subreddit> can be a subreddit or multi (ex: "pics+science"). If omitted, results from the user's front page will be returned-- i.e. what you would see if you visited reddit.com as that user. 
 
-`view` is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
+I<view> is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
 		
 fetch_links is an alias for get_links.
 
@@ -1112,11 +1163,11 @@ fetch_links is an alias for get_links.
 
     get_permalink ( $comment_id, $post_id )
 	
-Returns a permalink for `$comment_id`. **If you already have a [Comment](classes/comment) object, use its get_permalink function instead**, aka `$comment->get_permalink()`. 
+Returns a permalink for I<$comment_id>. B<If you already have a Comment object, use its get_permalink function instead>, ala C<$comment->get_permalink()>. 
 
 This version causes an extra request because it has to ask Reddit for the parent post's URL first, while a Comment object already has that information. It's provided for backwards compatibility, and for the rare case when you may have a comment's ID but not a comment object (perhaps you have a list of IDs stored in a database). It may be deprecated in the future.
 
-`$comment_id` and `$post_id` can be either fullnames or short IDs.
+I<$comment_id> and I<$post_id> can be either fullnames or short IDs.
 
 =item get_subreddit_comments
 
@@ -1127,7 +1178,7 @@ Returns a list of Comment objects from a subreddit or multi.
 
 All arguments are optional. If subreddit is omitted the account's "front page" subreddits are returned (i.e. what you see when you visit reddit.com and are logged in). 
 
-`view` is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
+I<view> is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
 
 =item get_token
 
@@ -1140,11 +1191,11 @@ Get an Oauth token from Reddit. This is analogous to the old login function, and
     get_user ( [ user => $username ,] [ view => USER_OVERVIEW ,]
                [ limit => DEFAULT_LIMIT ,][ before => undef ,] [ after => undef ,]  )
 			   
-Get information about a user, where `view` is one of the [user constants](constants): overview, comments, submitted, gilded, upvoted, downvoted, hidden, or saved. Defaults to overview, which shows the user's most recent comments and posts.
+Get information about a user, where I<view> is one of the USER constants: overview, comments, submitted, gilded, upvoted, downvoted, hidden, or saved. Defaults to overview, which shows the user's most recent comments and posts.
 
 Note that if you try to get the upvoted, downvoted, hidden, or saved activity for a user other than yourself, Reddit will return a 403 error, so be sure to wrap requests in a try/catch (L<http://redditclient.readthedocs.org/en/latest/examples/#catch-exceptions>) if there's any chance that might happen. (Of course, all requests should be wrapped in a try/catch anyway, the internet being an unpredictable place.)
 
-The result can be a list of Links, Comments, or a mix of both, depending on what `view` you requested. You can determine which is which by looking at the type property, which is "t1" for comments and "t3" for posts.
+The result can be a list of Links, Comments, or a mix of both, depending on what I<view> you requested. You can determine which is which by looking at the type property, which is "t1" for comments and "t3" for posts.
 
 =item has_token
 
@@ -1162,30 +1213,30 @@ Hide a post.
 
     info ( $fullname )
 
-Returns a hash of information about `$fullname`. `$fullname` can be any of the 8 types of thing.
+Returns a hash of information about I<$fullname>. I<$fullname> can be any of the 8 types of thing.
 
 =item list_subreddits
 
     list_subreddits ( [ view => SUBREDDITS_HOME ,] [ limit => DEFAULT_LIMIT ,]
                       [ before => undef ,] [ after => undef ,]  )
 
-Returns a list of subreddits, where `view` is one of the SUBREDDIT constants. 
+Returns a list of subreddits, where I<view> is one of the SUBREDDIT constants. 
 
-An alias function is provided for each view type, which is the same as calling `list_subreddits` with the view already provided:
+An alias function is provided for each view type, which is the same as calling C<list_subreddits> with the view already provided:
 
 =over
 
-* contrib_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+C<contrib_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )>
 
-* home_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+C<home_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )>
 
-* mod_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+C<mod_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )>
 
-* my_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+C<my_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )>
 
-* new_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+C<new_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )>
 
-* popular_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+C<popular_subreddits ( [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )>
 
 =back
 
@@ -1199,7 +1250,7 @@ Mark everything in your inbox as read. May take some time to complete.
 
     me()
 
-Return an Account object that contains information about the logged in account. Aside from static account information it contains the `has_mail` property, which will be true if there is anything in your inbox.
+Return an Account object that contains information about the logged in account. Aside from static account information it contains the I<has_mail> property, which will be true if there is anything in your inbox.
 
 =item new 
 
@@ -1208,7 +1259,7 @@ Return an Account object that contains information about the logged in account.
 
 Instantiate a Reddit::Client object. Optionally get an Oauth token (analogous to logging in) at the same time. If any of the four optional arguments are used, all are required.
 
-`$user_agent` is always required, and should be something descriptive that uniquely identifies your app. The API Rules (L<https://github.com/reddit/reddit/wiki/API#rules>) say it should be "something unique and descriptive, including the target platform, a unique application identifier, a version string, and your username as contact information".
+I<$user_agent> is always required, and should be something descriptive that uniquely identifies your app. The API Rules (L<https://github.com/reddit/reddit/wiki/API#rules>) say it should be "something unique and descriptive, including the target platform, a unique application identifier, a version string, and your username as contact information".
 
 It also includes this warning: "**NEVER lie about your user-agent.** This includes spoofing popular browsers and spoofing other bots. We will ban liars with extreme prejudice."
 
@@ -1222,37 +1273,37 @@ Save a post or comment.
 
     send_message ( to => $username, subject => $subject, text => $message )
 
-Send a private message to `$username`. `$subject` is limited to 100 characters.
+Send a private message to I<$username>. I<$subject> is limited to 100 characters.
 
 =item set_post_flair
 
     set_post_flair ( subreddit => $subreddit, post_id => $post_id_or_fullname, flair_template_id => $flair_id )
 	
-Set the flair on a post. The 'flair_template_id' is acquired via `get_flair_options`.
+Set the flair on a post. The 'flair_template_id' is acquired via I<get_flair_options>.
 
 =item set_user_flair
 
     set_user_flair ( subreddit => $subreddit, username => $username, flair_template_id => $flair_id )
 	
-Set the flair for a user. The 'flair_template_id' is acquired via `get_flair_options`.
+Set the flair for a user. The 'flair_template_id' is acquired via I<get_flair_options>.
 
 =item submit_comment 
 
     submit_comment ( parent_id => $fullname, text => $text)
 
-Submit a comment under `$fullname`, which must be a post or comment. Returns fullname of the new comment.
+Submit a comment under I<$fullname>, which must be a post or comment. Returns fullname of the new comment.
 
 =item submit_link 
 
     submit_link ( subreddit => $subreddit, title => $title, url => $url, [ inbox_replies => 1 ] )
 
-Submit a link. Returns the fullname of the new post. If `inbox_replies` is defined and is false, disable inbox replies for that post.
+Submit a link. Returns the fullname of the new post. If I<inbox_replies> is defined and is false, disable inbox replies for that post.
 
 =item submit_text 
 
     submit_text ( subreddit => $subreddit, title => $title, text => $text, [ inbox_replies => 1 ] )
 
-Submit a text post. Returns the fullname of the new post. If `inbox_replies` is defined and is false, disable inbox replies for that post.
+Submit a text post. Returns the fullname of the new post. If I<inbox_replies> is defined and is false, disable inbox replies for that post.
 
 =item unhide 
 
